@@ -90,21 +90,23 @@ gclue_service_location_get_property (GObject    *object,
         {
                 GClueDBusLocation *location;
                 GClueLocation *loc;
-                gdouble altitude;
+                GVariant *timestamp;
+                guint64 sec, usec;
 
                 location = GCLUE_DBUS_LOCATION (object);
-                loc = gclue_location_new_with_description
+
+                timestamp = gclue_dbus_location_get_timestamp (location);
+                g_variant_get (timestamp, "(tt)", &sec, &usec);
+
+                loc = gclue_location_new_full
                         (gclue_dbus_location_get_latitude (location),
                          gclue_dbus_location_get_longitude (location),
                          gclue_dbus_location_get_accuracy (location),
+                         gclue_dbus_location_get_speed (location),
+                         gclue_dbus_location_get_heading (location),
+                         gclue_dbus_location_get_altitude (location),
+                         sec,
                          gclue_dbus_location_get_description (location));
-                gclue_location_set_speed
-                        (loc, gclue_dbus_location_get_speed (location));
-                gclue_location_set_heading
-                        (loc, gclue_dbus_location_get_heading (location));
-                altitude = gclue_dbus_location_get_altitude (location);
-                if (altitude != GEOCODE_LOCATION_ALTITUDE_UNKNOWN)
-                        g_object_set (loc, "altitude", altitude, NULL);
 
                 g_value_take_object (value, loc);
                 break;
@@ -142,6 +144,7 @@ gclue_service_location_set_property (GObject      *object,
                 GClueLocation *loc;
                 gdouble altitude;
                 GeocodeLocation *g_loc;
+                GVariant *timestamp;
 
                 location = GCLUE_DBUS_LOCATION (object);
                 loc = g_value_get_object (value);
@@ -158,6 +161,12 @@ gclue_service_location_set_property (GObject      *object,
                         (location, gclue_location_get_speed (loc));
                 gclue_dbus_location_set_heading
                         (location, gclue_location_get_heading (loc));
+                timestamp = g_variant_new
+                        ("(tt)",
+                         (guint64) geocode_location_get_timestamp (g_loc),
+                         (guint64) 0);
+                gclue_dbus_location_set_timestamp
+                        (location, timestamp);
                 altitude = geocode_location_get_altitude (g_loc);
                 if (altitude != GEOCODE_LOCATION_ALTITUDE_UNKNOWN)
                         gclue_dbus_location_set_altitude (location, altitude);
